@@ -364,7 +364,13 @@ class Runtime(object):
             else:
                 self.arches = self.group_config.get('arches', ['x86_64'])
 
-            self.repos = Repos(self.group_config.repos, self.arches)
+            # If specified, signed repo files will be generated to enforce signature checks.
+            self.gpgcheck = self.group_config.build_profiles.image.signed.gpgcheck
+            if self.gpgcheck is Missing:
+                # We should only really be building the latest release with unsigned RPMs, so default to True
+                self.gpgcheck = True
+
+            self.repos = Repos(self.group_config.repos, self.arches, self.gpgcheck)
             self.freeze_automation = self.group_config.freeze_automation or FREEZE_AUTOMATION_NO
 
             if validate_content_sets:
@@ -610,8 +616,8 @@ class Runtime(object):
         levels = list(image_lists.keys())
         levels.sort()
         self.image_order = []
-        for l in levels:
-            for i in image_lists[l]:
+        for level in levels:
+            for i in image_lists[level]:
                 if i not in self.image_order:
                     self.image_order.append(i)
 
@@ -840,7 +846,7 @@ class Runtime(object):
             self.logger.info(f'Updating cache directory for git remote: {remote_url}')
             # Fire and forget this fetch -- just used to keep cache as fresh as possible
             exectools.fire_and_forget(repo_dir, 'git fetch --all')
-            gitargs.extend(['--reference-if-able', repo_dir])
+            gitargs.extend(['--dissociate', '--reference-if-able', repo_dir])
 
         self.logger.info(f'Cloning to: {target_dir}')
 
